@@ -1,4 +1,4 @@
-"""验证 Markdown 降级为纯文本时的反转义逻辑。"""
+"""Verify anti-escaping logic when downgrading Markdown to plain text."""
 
 from __future__ import annotations
 
@@ -11,12 +11,12 @@ import bot
 
 @pytest.mark.asyncio()
 async def test_markdown_guard_plain_fallback_preserves_original() -> None:
-    """确保纯文本回退时返回原始内容（含必要转义）。"""
+    """Ensure that plain text fallback returns the original content (with necessary escaping)."""
 
     delivered: list[str] = []
 
     class _DummyMethod(TelegramMethod):
-        """构造最小化的 TelegramMethod 以便创建异常对象。"""
+        """Construct a minimal TelegramMethod for creating exception objects."""
 
         __returning__ = bool
 
@@ -24,10 +24,10 @@ async def test_markdown_guard_plain_fallback_preserves_original() -> None:
         def __api_method__(self) -> str:
             return "testMethod"
 
-        def build_response(self, data, bot):  # pragma: no cover - 测试不会触发
+        def build_response(self, data, bot):  # pragma: no cover - Test won't trigger
             return True
 
-        def build_request(self, bot):  # pragma: no cover - 测试不会触发
+        def build_request(self, bot):  # pragma: no cover - Test won't trigger
             return "testMethod", {}
 
     async def _failing_sender(_: str) -> None:
@@ -36,7 +36,7 @@ async def test_markdown_guard_plain_fallback_preserves_original() -> None:
     async def _raw_sender(payload: str) -> None:
         delivered.append(payload)
 
-    original = "测试 \\_Markdown\\_ 转义"
+    original = "test \\_Markdown\\_ escape"
     result = await bot._send_with_markdown_guard(original, _failing_sender, raw_sender=_raw_sender)
 
     assert delivered and delivered[0] == original
@@ -47,22 +47,22 @@ async def test_markdown_guard_plain_fallback_preserves_original() -> None:
 @pytest.mark.parametrize(
     "original",
     [
-        "条目 A\\)",
-        "任务编码：/TASK\\_0022",
-        "配置文件 config\\.json",
-        "版本号 3\\.11\\.4",
-        "保留连字符 use\\-case",
-        "强调 \\*重要\\*",
-        "变量 \\_value\\_",
-        "选项 A\\|B",
-        "集合 \\{a, b\\}",
-        "说明 test\\.",
+        "Entry A\\)",
+        "Task code:/TASK\\_0022",
+        "Configuration file config\\.json",
+        "Version number 3\\.11\\.4",
+        "Keep hyphens use\\-case",
+        "emphasize \\*important\\*",
+        "Variable \\_value\\_",
+        "Option A\\|B",
+        "gather \\{a, b\\}",
+        "Description test\\.",
     ],
 )
 async def test_markdown_guard_plain_fallback_force_unescape(
     original: str,
 ) -> None:
-    """验证纯文本回退会直接返回原始字符串。"""
+    """Validating plain text fallback returns the original string directly."""
 
     delivered: list[str] = []
 
@@ -73,10 +73,10 @@ async def test_markdown_guard_plain_fallback_force_unescape(
         def __api_method__(self) -> str:
             return "testMethod"
 
-        def build_response(self, data, bot):  # pragma: no cover - 测试不会触发
+        def build_response(self, data, bot):  # pragma: no cover - Test won't trigger
             return True
 
-        def build_request(self, bot):  # pragma: no cover - 测试不会触发
+        def build_request(self, bot):  # pragma: no cover - Test won't trigger
             return "testMethod", {}
 
     async def _failing_sender(_: str) -> None:
