@@ -1,4 +1,4 @@
-"""vibego 命令入口与子命令实现。"""
+"""Entry point and subcommand implementations for the vibego CLI."""
 
 from __future__ import annotations
 
@@ -27,32 +27,32 @@ BOTFATHER_URL = "https://core.telegram.org/bots#botfather"
 
 
 def _find_repo_root() -> Path:
-    """推导当前仓库根目录。"""
+    """Determine the current repository root."""
 
     return config.PACKAGE_ROOT
 
 
 def _prompt_token(default: Optional[str] = None) -> str:
-    """交互式获取 Telegram Bot Token。"""
+    """Interactively read the Telegram Bot token from stdin."""
 
-    prompt = "请输入 Master Bot 的 Token"
+    prompt = "Enter the Master Bot token"
     if default:
-        prompt += f"（直接回车沿用当前值）"
-    prompt += "："
+        prompt += " (press Enter to keep the existing value)"
+    prompt += ": "
     while True:
         value = input(prompt).strip()
         if not value and default:
             value = default
         if not value:
-            print("Token 不能为空。若尚未创建 Bot，请参考官方指引：", BOTFATHER_URL)
+            print("Token cannot be empty. Follow the official guide if you need to create a bot:", BOTFATHER_URL)
             continue
         if TOKEN_PATTERN.match(value):
             return value
-        print("Token 格式看起来不正确，请确认后重试。官方获取方式：", BOTFATHER_URL)
+        print("The token format looks invalid. Please verify and retry. Official instructions:", BOTFATHER_URL)
 
 
 def _ensure_projects_assets() -> None:
-    """保证 projects.json 与 master.db 均已初始化。"""
+    """Ensure ``projects.json`` and ``master.db`` exist and are initialised."""
 
     config.ensure_directories()
     if not config.PROJECTS_JSON.exists():
@@ -61,7 +61,7 @@ def _ensure_projects_assets() -> None:
 
 
 def _virtualenv_paths(venv_dir: Path) -> Tuple[Path, Path]:
-    """返回虚拟环境的 python 与 pip 路径。"""
+    """Return the Python and pip executables inside the virtual environment."""
 
     if os.name == "nt":
         bin_dir = venv_dir / "Scripts"
@@ -71,46 +71,46 @@ def _virtualenv_paths(venv_dir: Path) -> Tuple[Path, Path]:
 
 
 def _ensure_virtualenv(repo_root: Path) -> Tuple[Path, Path]:
-    """在 runtime 目录中创建/升级虚拟环境并安装依赖。"""
+    """Create or upgrade the runtime virtual environment and install dependencies."""
 
     venv_dir = config.RUNTIME_DIR / "venv"
     python_exec, pip_exec = _virtualenv_paths(venv_dir)
     if not venv_dir.exists():
-        print("正在创建虚拟环境:", venv_dir)
+        print("Creating virtual environment:", venv_dir)
         subprocess.run([sys.executable, "-m", "venv", str(venv_dir)], check=True)
     if not python_exec.exists():
-        raise RuntimeError(f"未找到虚拟环境 python: {python_exec}")
+        raise RuntimeError(f"Virtual environment Python not found: {python_exec}")
     if not pip_exec.exists():
-        raise RuntimeError(f"未找到虚拟环境 pip: {pip_exec}")
+        raise RuntimeError(f"Virtual environment pip not found: {pip_exec}")
 
     marker = venv_dir / ".requirements.timestamp"
     req_file = config.ensure_worker_requirements_copy()
     if not marker.exists() or req_file.stat().st_mtime > marker.stat().st_mtime:
-        print("正在安装 Python 依赖（该步骤可能耗时）...")
+        print("Installing Python dependencies (this may take a while)...")
         install_requirements(req_file, pip_executable=pip_exec)
         marker.touch()
     return python_exec, pip_exec
 
 
 def command_init(args: argparse.Namespace) -> None:
-    """实现 `vibego init`。"""
+    """Implementation of ``vibego init``."""
 
     config.ensure_directories()
     env_values = config.parse_env_file(config.ENV_FILE)
 
     if not python_version_ok():
-        print("警告：当前 Python 版本低于 3.11，建议升级以获得完整功能。")
+        print("Warning: running on Python earlier than 3.11; upgrade for full functionality.")
 
     missing = check_cli_dependencies()
     if missing:
-        print("依赖检查发现缺失项：")
+        print("Missing dependencies detected:")
         for item in missing:
             print("-", item)
-        print("请先安装上述依赖后再执行初始化。")
+        print("Install the listed dependencies and rerun the command.")
         return
 
     if config.ENV_FILE.exists() and not args.force:
-        print("检测到已存在的 .env。若需覆盖请使用 --force。")
+        print(".env already exists. Use --force to overwrite.")
     default_token = env_values.get("MASTER_BOT_TOKEN")
     token = args.token or _prompt_token(default_token)
     env_values["MASTER_BOT_TOKEN"] = token
@@ -122,25 +122,25 @@ def command_init(args: argparse.Namespace) -> None:
     config.dump_env_file(config.ENV_FILE, env_values)
     _ensure_projects_assets()
 
-    print("初始化完成，配置目录：", config.CONFIG_ROOT)
-    print("可执行步骤：")
-    print(f"  1. 如需代理，请编辑 {config.ENV_FILE} 调整相关变量。")
-    print("  2. 运行 `vibego start` 启动 master 服务。")
+    print("Initialisation complete. Configuration directory:", config.CONFIG_ROOT)
+    print("Next steps:")
+    print(f"  1. Edit {config.ENV_FILE} to configure proxy settings if needed.")
+    print("  2. Run `vibego start` to launch the master service.")
 
 
 def _load_env_or_fail() -> Dict[str, str]:
-    """读取 .env，若不存在则提示用户执行 init。"""
+    """Read ``.env`` and raise when initialisation has not been performed."""
 
     if not config.ENV_FILE.exists():
-        raise RuntimeError(f"未检测到 {config.ENV_FILE}，请先执行 `vibego init`。")
+        raise RuntimeError(f"{config.ENV_FILE} not found. Please run `vibego init` first.")
     values = config.parse_env_file(config.ENV_FILE)
     if "MASTER_BOT_TOKEN" not in values or not values["MASTER_BOT_TOKEN"].strip():
-        raise RuntimeError("MASTER_BOT_TOKEN 未定义，请重新执行 `vibego init`。")
+        raise RuntimeError("MASTER_BOT_TOKEN is missing. Rerun `vibego init`.")
     return values
 
 
 def _build_master_env(base_env: Dict[str, str]) -> Dict[str, str]:
-    """组装 master.py 所需的环境变量。"""
+    """Construct the environment variables required by ``master.py``."""
 
     env = os.environ.copy()
     env.update(base_env)
@@ -164,13 +164,13 @@ def _build_master_env(base_env: Dict[str, str]) -> Dict[str, str]:
 
 
 def _write_pid(pid: int) -> None:
-    """记录 master 进程 PID。"""
+    """Persist the master process PID."""
 
     config.MASTER_PID_FILE.write_text(str(pid), encoding="utf-8")
 
 
 def _read_pid() -> Optional[int]:
-    """读取 master 进程 PID。"""
+    """Return the persisted master PID if present."""
 
     if not config.MASTER_PID_FILE.exists():
         return None
@@ -179,40 +179,40 @@ def _read_pid() -> Optional[int]:
 
 
 def command_start(args: argparse.Namespace) -> None:
-    """实现 `vibego start`。"""
+    """Implementation of ``vibego start``."""
 
     env_values = _load_env_or_fail()
     _ensure_projects_assets()
 
     if not python_version_ok():
         raise RuntimeError(
-            "当前 Python 版本为 3.11 以下，无法运行 master。"
-            "请通过 `brew install python@3.11` 或其他方式升级后重试。"
+            "Python earlier than 3.11 cannot run the master. "
+            "Upgrade via `brew install python@3.11` or another method."
         )
 
     missing = check_cli_dependencies()
     if missing:
-        print("依赖检查发现缺失项：")
+        print("Missing dependencies detected:")
         for item in missing:
             print("-", item)
-        print("请补充依赖后重新执行。")
+        print("Install the listed dependencies before retrying.")
         return
 
     repo_root = _find_repo_root()
     try:
         python_exec, _ = _ensure_virtualenv(repo_root)
     except subprocess.CalledProcessError as exc:
-        raise RuntimeError(f"虚拟环境初始化失败：{exc}") from exc
+        raise RuntimeError(f"Virtual environment initialisation failed: {exc}") from exc
 
     master_env = _build_master_env(env_values)
     log_file = config.LOG_FILE
     log_file.parent.mkdir(parents=True, exist_ok=True)
 
     if _read_pid():
-        print("检测到 master 已启动，如需重启请先执行 `vibego stop`。")
+        print("Master already running. Execute `vibego stop` before restarting.")
         return
 
-    print("正在启动 master 服务...")
+    print("Starting master service...")
     with open(log_file, "a", encoding="utf-8") as log_fp:
         process = subprocess.Popen(
             [str(python_exec), "master.py"],
@@ -226,26 +226,26 @@ def command_start(args: argparse.Namespace) -> None:
 
     time.sleep(2)
     if process.poll() is not None:
-        raise RuntimeError("master 进程启动失败，请检查日志。")
+        raise RuntimeError("Master process failed to start. Check the logs.")
 
-    print("master 已启动，PID:", process.pid)
-    print("日志文件：", log_file)
-    print("请在 Telegram 中向 Bot 发送 /start 以完成授权流程。")
+    print("Master started. PID:", process.pid)
+    print("Log file:", log_file)
+    print("Send /start to the bot in Telegram to complete authorisation.")
 
 
 def command_stop(args: argparse.Namespace) -> None:
-    """实现 `vibego stop`。"""
+    """Implementation of ``vibego stop``."""
 
     pid = _read_pid()
     if not pid:
-        print("未检测到正在运行的 master。")
+        print("Master process not detected.")
         return
 
-    print("正在停止 master（PID =", pid, ")...")
+    print("Stopping master (PID =", pid, ")...")
     try:
         os.kill(pid, signal.SIGTERM)
     except ProcessLookupError:
-        print("进程不存在，视为已停止。")
+        print("Process not found; treating as already stopped.")
     else:
         for _ in range(20):
             time.sleep(0.5)
@@ -254,13 +254,13 @@ def command_stop(args: argparse.Namespace) -> None:
             except ProcessLookupError:
                 break
         else:
-            print("master 未在预期时间内退出，如仍存在请手动检查。")
+            print("Master did not exit within the expected time. Please investigate manually.")
     config.MASTER_PID_FILE.unlink(missing_ok=True)
-    print("停止完成。")
+    print("Stop completed.")
 
 
 def command_status(args: argparse.Namespace) -> None:
-    """实现 `vibego status`。"""
+    """Implementation of ``vibego status``."""
 
     env_values = config.parse_env_file(config.ENV_FILE)
     pid = _read_pid()
@@ -289,7 +289,7 @@ def command_status(args: argparse.Namespace) -> None:
 
 
 def command_doctor(args: argparse.Namespace) -> None:
-    """实现 `vibego doctor`，输出自检结果。"""
+    """Implementation of ``vibego doctor``. Outputs a diagnostic report."""
 
     report = {
         "python_version": sys.version,
@@ -305,44 +305,44 @@ def command_doctor(args: argparse.Namespace) -> None:
 
 
 def build_parser() -> argparse.ArgumentParser:
-    """构建最外层 argparse 解析器。"""
+    """Build the top-level argparse parser."""
 
-    parser = argparse.ArgumentParser(prog="vibego", description="vibego CLI 工具")
+    parser = argparse.ArgumentParser(prog="vibego", description="vibego CLI utilities")
     parser.add_argument(
         "--config-dir",
         dest="config_dir",
-        help="自定义配置目录（默认 ~/.config/vibego）",
+        help="Custom configuration directory (default ~/.config/vibego)",
     )
     subparsers = parser.add_subparsers(dest="command", required=True)
 
-    init_parser = subparsers.add_parser("init", help="初始化配置目录与 master token")
-    init_parser.add_argument("--token", help="直接传入 master bot token，避免交互输入")
-    init_parser.add_argument("--force", action="store_true", help="覆盖已有 .env 配置")
+    init_parser = subparsers.add_parser("init", help="Initialise the configuration directory and master token")
+    init_parser.add_argument("--token", help="Provide the master bot token directly to avoid interactive input")
+    init_parser.add_argument("--force", action="store_true", help="Overwrite the existing .env file")
     init_parser.set_defaults(func=command_init)
 
-    start_parser = subparsers.add_parser("start", help="启动 master 服务")
+    start_parser = subparsers.add_parser("start", help="Start the master service")
     start_parser.set_defaults(func=command_start)
 
-    stop_parser = subparsers.add_parser("stop", help="停止 master 服务")
+    stop_parser = subparsers.add_parser("stop", help="Stop the master service")
     stop_parser.set_defaults(func=command_stop)
 
-    status_parser = subparsers.add_parser("status", help="查看当前运行状态")
+    status_parser = subparsers.add_parser("status", help="Display the current running status")
     status_parser.set_defaults(func=command_status)
 
-    doctor_parser = subparsers.add_parser("doctor", help="运行依赖与配置自检")
+    doctor_parser = subparsers.add_parser("doctor", help="Run dependency and configuration diagnostics")
     doctor_parser.set_defaults(func=command_doctor)
 
     return parser
 
 
 def main(argv: Optional[Sequence[str]] = None) -> None:
-    """CLI 主入口。"""
+    """CLI main entrypoint."""
 
     parser = build_parser()
     args = parser.parse_args(argv)
     if args.config_dir:
         os.environ["VIBEGO_CONFIG_DIR"] = args.config_dir
-        # 重新加载路径设置
+        # Reload path configuration after overriding the config directory.
         from importlib import reload
 
         reload(config)
@@ -350,7 +350,7 @@ def main(argv: Optional[Sequence[str]] = None) -> None:
     try:
         args.func(args)
     except Exception as exc:  # pylint: disable=broad-except
-        print("执行失败：", exc)
+        print("Execution failed:", exc)
         sys.exit(1)
 
 
